@@ -3,10 +3,13 @@ mxEvalPlots_UI <- function(id) {
   ns <- NS(id)
   tagList(
     selectInput(ns('mxEvalSel'), label = "Select evaluation statistic",
-                choices = list("Select Stat..." = '', "average AUC test" = 'avg.test.AUC', 
-                               "average AUC diff" = 'avg.diff.AUC', "average OR mtp" = 'avg.test.orMTP',
-                               "average OR 10%" = 'avg.test.or10pct', "delta AICc" = 'delta.AICc'), 
-                selected = 'avg.test.AUC'),
+                choices = list("Select Stat..." = '', 
+                               "average AUC validation" = 'auc.val', 
+                               "average AUC diff" = 'auc.diff', 
+                               "average OR mtp" = 'or.mtp',
+                               "average OR 10%" = 'or.10p', 
+                               "delta AICc" = 'delta.AICc'), 
+                selected = 'auc.val'),
     HTML('<hr>'),
     strong("Download Maxent evaluation plot (.png)"), br(), br(),
     downloadButton(ns('dlMxEvalPlot'), "Download")
@@ -33,11 +36,12 @@ mxEvalPlots_MOD <- function(input, output, session, rvs) {
       filename = function() {paste0(spName(), "_",rvs$mxEvalSel,"_EvalPlot.png")},
       content = function(file) {
         png(file)
-        evalPlot(rvs$modRes, input$mxEvalSel)
+        plot(ENMeval::evalplot.stats(new("ENMevaluation", results = rvs$modRes), 
+                                     rvs$mxEvalSel, "rm", "fc"))
         dev.off()
       }
     )
-    
-    evalPlot(rvs$modRes, input$mxEvalSel)
+    plot(ENMeval::evalplot.stats(new("ENMevaluation", results = rvs$modRes), 
+                                 rvs$mxEvalSel, "rm", "fc"))
   })
 }
